==> duckdb_0.3.2-2.tar.gz: duckdb/src/duckdb/amalgamation-15.cpp <==
#include "src/parser/transform/tableref/transform_subquery.cpp"

#include "src/parser/transform/tableref/transform_table_function.cpp"

#include "src/parser/transform/tableref/transform_tableref.cpp"

#include "src/parser/transformer.cpp"

#include "src/planner/bind_context.cpp"

#include "src/planner/binder.cpp"

#include "src/planner/binder/expression/bind_aggregate_expression.cpp"

#include "src/planner/binder/expression/bind_between_expression.cpp"

#include "src/planner/binder/expression/bind_case_expression.cpp"

#include "src/planner/binder/expression/bind_cast_expression.cpp"

#include "src/planner/binder/expression/bind_collate_expression.cpp"

#include "src/planner/binder/expression/bind_columnref_expression.cpp"

#include "src/planner/binder/expression/bind_comparison_expression.cpp"

#include "src/planner/binder/expression/bind_conjunction_expression.cpp"

#include "src/planner/binder/expression/bind_constant_expression.cpp"

#include "src/planner/binder/expression/bind_function_expression.cpp"

#include "src/planner/binder/expression/bind_lambda.cpp"

#include "src/planner/binder/expression/bind_macro_expression.cpp"

#include "src/planner/binder/expression/bind_operator_expression.cpp"

#include "src/planner/binder/expression/bind_parameter_expression.cpp"

#include "src/planner/binder/expression/bind_positional_reference_expression.cpp"

#include "src/planner/binder/expression/bind_subquery_expression.cpp"

#include "src/planner/binder/expression/bind_unnest_expression.cpp"

#include "src/planner/binder/expression/bind_window_expression.cpp"

#include "src/planner/binder/query_node/bind_recursive_cte_node.cpp"

#include "src/planner/binder/query_node/bind_select_node.cpp"

#include "src/planner/binder/query_node/bind_setop_node.cpp"

#include "src/planner/binder/query_node/plan_query_node.cpp"

#include "src/planner/binder/query_node/plan_recursive_cte_node.cpp"

#include "src/planner/binder/query_node/plan_select_node.cpp"

#include "src/planner/binder/query_node/plan_setop.cpp"

#include "src/planner/binder/query_node/plan_subquery.cpp"

#include "src/planner/binder/statement/bind_call.cpp"

#include "src/planner/binder/statement/bind_copy.cpp"

#include "src/planner/binder/statement/bind_create.cpp"

#include "src/planner/binder/statement/bind_create_table.cpp"

#include "src/planner/binder/statement/bind_delete.cpp"

#include "src/planner/binder/statement/bind_drop.cpp"

#include "src/planner/binder/statement/bind_explain.cpp"

#include "src/planner/binder/statement/bind_export.cpp"

#include "src/planner/binder/statement/bind_insert.cpp"

#include "src/planner/binder/statement/bind_load.cpp"

#include "src/planner/binder/statement/bind_pragma.cpp"

#include "src/planner/binder/statement/bind_relation.cpp"

#include "src/planner/binder/statement/bind_select.cpp"

#include "src/planner/binder/statement/bind_set.cpp"

==> duckdb_0.3.4-1.tar.gz: duckdb/src/duckdb/amalgamation-15.cpp <==
#include "src/parser/transform/tableref/transform_from.cpp"

#include "src/parser/transform/tableref/transform_join.cpp"

#include "src/parser/transform/tableref/transform_subquery.cpp"

#include "src/parser/transform/tableref/transform_table_function.cpp"

#include "src/parser/transform/tableref/transform_tableref.cpp"

#include "src/parser/transformer.cpp"

#include "src/planner/bind_context.cpp"

#include "src/planner/binder.cpp"

#include "src/planner/binder/expression/bind_aggregate_expression.cpp"

#include "src/planner/binder/expression/bind_between_expression.cpp"

#include "src/planner/binder/expression/bind_case_expression.cpp"

#include "src/planner/binder/expression/bind_cast_expression.cpp"

#include "src/planner/binder/expression/bind_collate_expression.cpp"

#include "src/planner/binder/expression/bind_columnref_expression.cpp"

#include "src/planner/binder/expression/bind_comparison_expression.cpp"

#include "src/planner/binder/expression/bind_conjunction_expression.cpp"

#include "src/planner/binder/expression/bind_constant_expression.cpp"

#include "src/planner/binder/expression/bind_function_expression.cpp"

#include "src/planner/binder/expression/bind_lambda.cpp"

#include "src/planner/binder/expression/bind_macro_expression.cpp"

#include "src/planner/binder/expression/bind_operator_expression.cpp"

#include "src/planner/binder/expression/bind_parameter_expression.cpp"

#include "src/planner/binder/expression/bind_positional_reference_expression.cpp"

#include "src/planner/binder/expression/bind_subquery_expression.cpp"

#include "src/planner/binder/expression/bind_unnest_expression.cpp"

#include "src/planner/binder/expression/bind_window_expression.cpp"

#include "src/planner/binder/query_node/bind_recursive_cte_node.cpp"

#include "src/planner/binder/query_node/bind_select_node.cpp"

#include "src/planner/binder/query_node/bind_setop_node.cpp"

#include "src/planner/binder/query_node/bind_table_macro_node.cpp"

#include "src/planner/binder/query_node/plan_query_node.cpp"

#include "src/planner/binder/query_node/plan_recursive_cte_node.cpp"

#include "src/planner/binder/query_node/plan_select_node.cpp"

#include "src/planner/binder/query_node/plan_setop.cpp"

#include "src/planner/binder/query_node/plan_subquery.cpp"

#include "src/planner/binder/statement/bind_call.cpp"

#include "src/planner/binder/statement/bind_copy.cpp"

#include "src/planner/binder/statement/bind_create.cpp"

#include "src/planner/binder/statement/bind_create_table.cpp"

#include "src/planner/binder/statement/bind_delete.cpp"

#include "src/planner/binder/statement/bind_drop.cpp"

#include "src/planner/binder/statement/bind_explain.cpp"

#include "src/planner/binder/statement/bind_export.cpp"

#include "src/planner/binder/statement/bind_insert.cpp"

#include "src/planner/binder/statement/bind_load.cpp"

#include "src/planner/binder/statement/bind_pragma.cpp"

#include "src/planner/binder/statement/bind_relation.cpp"
